"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const get_jsend_1 = require("../helpers/get-jsend");
const get_and_check_query_1 = require("../helpers/get-and-check-query");
/**
 * @api {delete} :port/=^.^=/history Clear a route history

 * @apiGroup HttpMocker
 * @apiVersion 0.4.0
 * @apiName DeleteRouteHistory
 * @apiDescription It clears a route history.
 *
 * @apiParam {String} path    The route path. It musts be a query param.
 * @apiParam {String} method  The route method. It musts be a query param.
 *
 *
 * @apiSuccessExample Success-Response:
 *     HTTP/1.1 204 OK
 */
class ClearHistoryHandler {
    constructor(mocker) {
        this.mocker = mocker;
    }
    handle(req) {
        return new Promise((resolve) => {
            let response = get_and_check_query_1.default(req);
            if (response.err)
                return resolve({
                    code: 400,
                    body: get_jsend_1.default({ statusCode: 400, data: undefined, message: response.err })
                });
            this.mocker.getRouteShelf().getItem(response.query.path, response.query.method)
                .then(() => {
                this.mocker.getRequestShelf().deleteRequests(response.query.method.toUpperCase() + response.query.path);
                resolve({
                    code: 204,
                    body: get_jsend_1.default({ statusCode: 204, data: undefined, message: undefined })
                });
            }).catch((code) => {
                resolve({
                    code: code,
                    body: get_jsend_1.default({ statusCode: code, data: undefined, message: 'route does not exist' })
                });
            });
        });
    }
}
exports.default = ClearHistoryHandler;
