/// <reference types="node" />
import { IncomingMessage } from 'http';
import IResponse from '../interfaces/IResponse';
/**
 * @api {post} /create Create a new HttpMocker

 * @apiGroup HttpMocker
 * @apiVersion 0.4.0
 * @apiName CreateHttpMocker
 * @apiDescription It creates a new HttpMocker.
 *
 * @apiSuccess {String} status Request status.
 * @apiSuccess {Object} data HttpMocker details.
 * @apiSuccess {Number} data.port HttpMocker port.
 * @apiSuccess {String} message Success message.
 *
 * @apiSuccessExample Success-Response:
 *     HTTP/1.1 200 OK
 *     {
 *       "status": "success",
 *       "data": {
 *         "port": 0000
 *       }
 *     }
 *
 * @apiError {String} status Request status.
 * @apiError {String} message Error message.

 * @apiErrorExample Error-Response:
 *     HTTP/1.1 500 Internal Server Error
 *     {
 *       "status": "error",
 *       "message": "no available port"
 *     }
 */
export default class CreateHttpMockerHandler {
    readonly hostname: string;
    private portsRange;
    private usedPorts;
    constructor(hostname: string, portsRange: number[]);
    handle(req: IncomingMessage): Promise<IResponse>;
    createHttpMocker(): Promise<IResponse>;
    private removePort;
}
