"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const get_jsend_1 = require("../helpers/get-jsend");
const httpMocker_1 = require("../mocker/httpMocker");
const methods_consts_1 = require("../consts/methods-consts");
const create_route_handler_1 = require("./create-route-handler");
const delete_route_handler_1 = require("./delete-route-handler");
const routes_getter_handler_1 = require("./routes-getter-handler");
const mocker_health_checker_handler_1 = require("./mocker-health-checker-handler");
const stop_mocker_handler_1 = require("./stop-mocker-handler");
const history_getter_handler_1 = require("./history-getter-handler");
const clear_history_handler_1 = require("./clear-history-handler");
const get_port_1 = require("../helpers/get_port");
const kitty_1 = require("../consts/kitty");
const create_ws_route_handler_1 = require("./create-ws-route-handler");
const delete_ws_route_handler_1 = require("./delete-ws-route-handler");
const update_route_handler_1 = require("./update-route-handler");
const route_getter_handler_1 = require("./route-getter-handler");
/**
 * @api {post} /create Create a new HttpMocker

 * @apiGroup HttpMocker
 * @apiVersion 0.4.0
 * @apiName CreateHttpMocker
 * @apiDescription It creates a new HttpMocker.
 *
 * @apiSuccess {String} status Request status.
 * @apiSuccess {Object} data HttpMocker details.
 * @apiSuccess {Number} data.port HttpMocker port.
 * @apiSuccess {String} message Success message.
 *
 * @apiSuccessExample Success-Response:
 *     HTTP/1.1 200 OK
 *     {
 *       "status": "success",
 *       "data": {
 *         "port": 0000
 *       }
 *     }
 *
 * @apiError {String} status Request status.
 * @apiError {String} message Error message.

 * @apiErrorExample Error-Response:
 *     HTTP/1.1 500 Internal Server Error
 *     {
 *       "status": "error",
 *       "message": "no available port"
 *     }
 */
class CreateHttpMockerHandler {
    constructor(hostname, portsRange) {
        this.usedPorts = [];
        this.hostname = hostname;
        this.portsRange = portsRange;
    }
    handle(req) {
        return this.createHttpMocker();
    }
    createHttpMocker() {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            let port = get_port_1.default(this.portsRange, this.usedPorts);
            if (!port) {
                return resolve({
                    code: 500,
                    body: get_jsend_1.default({ statusCode: 500, data: undefined, message: 'no available port' })
                });
            }
            const mocker = new httpMocker_1.default(this.hostname, port);
            mocker.loadServer();
            return mocker.runServer().then(() => {
                mocker.addRoute({
                    filters: { path: `/${kitty_1.RESERVED_PATH}/routes`, method: methods_consts_1.GET },
                    response: routes_getter_handler_1.default.prototype.handle.bind(new routes_getter_handler_1.default(mocker))
                });
                mocker.addRoute({
                    filters: { path: `/${kitty_1.RESERVED_PATH}/route`, method: methods_consts_1.GET },
                    response: route_getter_handler_1.default.prototype.handle.bind(new route_getter_handler_1.default(mocker))
                });
                mocker.addRoute({
                    filters: { path: `/${kitty_1.RESERVED_PATH}/route`, method: methods_consts_1.POST },
                    response: create_route_handler_1.default.prototype.handle.bind(new create_route_handler_1.default(mocker))
                });
                mocker.addRoute({
                    filters: { path: `/${kitty_1.RESERVED_PATH}/route`, method: methods_consts_1.PATCH },
                    response: update_route_handler_1.default.prototype.handle.bind(new update_route_handler_1.default(mocker))
                });
                mocker.addRoute({
                    filters: { path: `/${kitty_1.RESERVED_PATH}/ws-route`, method: methods_consts_1.POST },
                    response: create_ws_route_handler_1.default.prototype.handle.bind(new create_ws_route_handler_1.default(mocker))
                });
                mocker.addRoute({
                    filters: { path: `/${kitty_1.RESERVED_PATH}/ws-route`, method: methods_consts_1.DELETE },
                    response: delete_ws_route_handler_1.default.prototype.handle.bind(new delete_ws_route_handler_1.default(mocker))
                });
                mocker.addRoute({
                    filters: { path: `/${kitty_1.RESERVED_PATH}/route`, method: methods_consts_1.DELETE },
                    response: delete_route_handler_1.default.prototype.handle.bind(new delete_route_handler_1.default(mocker))
                });
                mocker.addRoute({
                    filters: { path: `/${kitty_1.RESERVED_PATH}/history`, method: methods_consts_1.GET },
                    response: history_getter_handler_1.default.prototype.handle.bind(new history_getter_handler_1.default(mocker))
                });
                mocker.addRoute({
                    filters: { path: `/${kitty_1.RESERVED_PATH}/history`, method: methods_consts_1.DELETE },
                    response: clear_history_handler_1.default.prototype.handle.bind(new clear_history_handler_1.default(mocker))
                });
                mocker.addRoute({
                    filters: { path: '/', method: methods_consts_1.GET },
                    response: mocker_health_checker_handler_1.default.prototype.handle.bind(new mocker_health_checker_handler_1.default())
                });
                mocker.addRoute({
                    filters: { path: '/', method: methods_consts_1.DELETE },
                    response: stop_mocker_handler_1.default.prototype.handle.bind(new stop_mocker_handler_1.default(mocker, CreateHttpMockerHandler.prototype.removePort.bind(this)))
                });
                this.usedPorts.push(port);
                let mockerInfoResponse = { port: port };
                return resolve({
                    code: 200, body: get_jsend_1.default({
                        statusCode: 200,
                        data: mockerInfoResponse,
                        message: 'mocker successfully created'
                    })
                });
            }).catch(() => {
                console.log(`Retrying to connect in another port, ${port} is in use.`);
                this.usedPorts.push(port);
                return resolve(this.createHttpMocker());
            });
        }));
    }
    removePort(mockerPort) {
        this.usedPorts = this.usedPorts.filter(port => {
            return port != mockerPort;
        });
    }
}
exports.default = CreateHttpMockerHandler;
