/// <reference types="node" />
import { IncomingMessage } from 'http';
import IResponse from '../interfaces/IResponse';
import IHttpMocker from '../interfaces/IHttpMocker';
/**
 * @api {post} :port/=^.^=/ws-route Create a new websocket route

 * @apiGroup HttpMocker
 * @apiVersion 0.4.0
 * @apiName CreateWSRoute
 * @apiDescription It creates a new websocket route in HttpMocker and automatically a pair called :port/ws-pair/ROUTE_PATH, everything sent in a side will be sent to the other, if there is no connection data will be storage and sent immediately when connected.
 *
 * @apiParam {Object} filters         The route filters.
 * @apiParam {String} filters.path    The route path.
 *
 * @apiSuccess {String} status Request status
 * @apiSuccess {String} message Success message
 *
 * @apiSuccessExample Success-Response:
 *     HTTP/1.1 200 OK
 *     {
 *       "status": "success",
 *       "message": "route successfully created"
 *     }
 *
 * @apiError {String} status Request status.
 * @apiError {String} message Error message.

 * @apiErrorExample Error-Response:
 *     HTTP/1.1 400 Bad Request
 *     {
 *        "status": "fail",
 *        "message": "request with invalid route path"
 *     }
 */
export default class CreateWsRouteHandler {
    private mocker;
    constructor(mocker: IHttpMocker);
    handle(req: IncomingMessage): Promise<IResponse>;
}
