"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const get_jsend_1 = require("../helpers/get-jsend");
const get_and_check_query_1 = require("../helpers/get-and-check-query");
/**
 * @api {delete} :port/=^.^=/route Delete a websocket route
 * @apiGroup HttpMocker
 * @apiVersion 0.4.0
 * @apiName DeleteWsRoute
 * @apiDescription It deletes a websocket route.
 *
 * @apiParam {String} path    The route path. It musts be a query param.
 *
 *
 * @apiSuccessExample Success-Response:
 *     HTTP/1.1 204 OK
 *
 * @apiError {String} status Request status.
 * @apiError {String} message Error message.

 * @apiErrorExample Error-Response:
 *     HTTP/1.1 404 Not Found
 *     {
 *       "status": "fail",
 *       "message": "route does not exist"
 *     }
 */
class DeleteWsRouteHandler {
    constructor(mocker) {
        this.mocker = mocker;
    }
    handle(req) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            let response = get_and_check_query_1.default(req);
            if (response.err)
                return resolve({
                    code: 400,
                    body: get_jsend_1.default({ statusCode: 400, data: undefined, message: response.err })
                });
            let ws = this.mocker.getWsShelf().getWs(response.query.path);
            if (!ws) {
                return resolve({
                    code: 404,
                    body: get_jsend_1.default({ statusCode: 404, data: undefined, message: 'route does not exist' })
                });
            }
            if (ws.routeWs.socket) {
                ws.routeWs.socket.close();
            }
            if (ws.routePairWs.socket) {
                ws.routePairWs.socket.close();
            }
            ws.routeWs.server.close();
            ws.routePairWs.server.close();
            this.mocker.getWsShelf().deleteWs(response.query.path);
            resolve({
                code: 204,
                body: get_jsend_1.default({ statusCode: 204, data: undefined, message: undefined })
            });
        }));
    }
}
exports.default = DeleteWsRouteHandler;
