"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const get_jsend_1 = require("../helpers/get-jsend");
const kitty_1 = require("../consts/kitty");
/**
 * @api {get} :port/=^.^=/routes Get HttpMocker routes

 * @apiGroup HttpMocker
 * @apiVersion 0.4.0
 * @apiName GetRoutes
 * @apiDescription It gets a HttpMocker routes.
 *
 * @apiSuccess {String} status Request status.
 * @apiSuccess {Object} data An array with routes.
 * @apiSuccess {Object} data.filters         The route filters.
 * @apiSuccess {String} data.filters.path    The route path. If with query, must be encoded.
 * @apiSuccess {String} data.filters.method  The route method.
 * @apiSuccess {Object} data.response        The route response.
 * @apiSuccess {Number} data.response.code   The route response code. It musts be between 100 and 600.
 * @apiSuccess {String} data.response.body   The route response body.
 *
 *
 * @apiSuccessExample Success-Response:
 *     HTTP/1.1 200 OK
 *    {
 *       "status": "success",
 *       "data": [
 *        {
 *         "filters":{
 *           "path": "/oi",
 *           "method": "GET"
 *         },
 *         "response":{
 *           "body": "test",
 *           "code": 200
 *         }
 *        }
 *       ]
 *     }
 */
class RoutesGetterHandler {
    constructor(mocker) {
        this.mocker = mocker;
    }
    handle(req) {
        return new Promise((resolve) => {
            let routes = this.mocker.getRouteShelf().getItems();
            resolve({
                code: 200,
                body: get_jsend_1.default({ statusCode: 200, data: hydrate(routes), message: undefined })
            });
        });
    }
}
exports.default = RoutesGetterHandler;
function hydrate(routes) {
    return routes.filter((route) => {
        return !route.filters.path.includes(`${kitty_1.RESERVED_PATH}`) && route.filters.path != `/`;
    });
}
