/// <reference types="node" />
import { IncomingMessage } from 'http';
import IResponse from '../interfaces/IResponse';
import IHttpMocker from '../interfaces/IHttpMocker';
/**
 * @api {patch} :port/=^.^=/route Update a route

 * @apiGroup HttpMocker
 * @apiVersion 0.4.0
 * @apiName UpdateRoute
 * @apiDescription It updates a route in HttpMocker
 *
 * @apiParam {String} path    The route path. It musts be a query param. If with query, must be encoded.
 * @apiParam {String} method  The route method. It musts be a query param.
 *
 * @apiParam {Object} [response]        The route response. It musts be set if does not exist a validator.
 * @apiParam {Number} response.code   The route response code. It musts be between 100 and 600.
 * @apiParam {String} response.body   The route response body.
 * @apiParam {Object[]} [validator]   The route request validator.
 * @apiParam {Object} validator.matchers   The validator matcher.
 * @apiParam {String||Object} validator.matchers.body   The validator body matcher.
 * @apiParam {String[String||Object]} validator.matchers.header   The validator header matcher. A object map with string keys and string or objects values.
 * @apiParam {String} validator.code   The code response when validator matched body.
 * @apiParam {String||Object} validator.body   The body response when validator matched body.
 *
 * @apiSuccess {String} status Request status
 * @apiSuccess {String} message Success message
 *
 * @apiSuccessExample Success-Response:
 *     HTTP/1.1 200 OK
 *     {
 *       "status": "success",
 *       "message": "route updated successfully"
 *     }
 *
 * @apiError {String} status Request status.
 * @apiError {String} message Error message.

 * @apiErrorExample Error-Response:
 *     HTTP/1.1 400 Bad Request
 *     {
 *        "status": "fail",
 *        "message": "route does not exist"
 *     }
 */
export default class UpdateRouteHandler {
    private mocker;
    constructor(mocker: IHttpMocker);
    handle(req: IncomingMessage): Promise<IResponse>;
}
