"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.printRequestsLog = exports.printDisconnected = exports.printConnected = exports.printWsLog = void 0;
const kitty_1 = require("../consts/kitty");
const chalk = require("chalk");
const perf_hooks_1 = require("perf_hooks");
function printWsLog(date, path, msg) {
    let repeatSpaceOnPath = 25 - path.length;
    if (repeatSpaceOnPath < 0)
        repeatSpaceOnPath = 0;
    console.log(`${chalk.yellow.bold(`${kitty_1.KITTY}`)} ${date} | ${chalk.bgBlue.bold(`  ws-message  `)} | ${chalk.gray.bold(`${' '.repeat(repeatSpaceOnPath)}${path}`)} | ${chalk.red.bold(`${msg}`)}`);
}
exports.printWsLog = printWsLog;
function printConnected(date, path) {
    console.log(`${chalk.yellow.bold(`${kitty_1.KITTY}`)} ${date} | ${chalk.green.bold(`connection opened on ${path}`)}`);
}
exports.printConnected = printConnected;
function printDisconnected(date, path) {
    console.log(`${chalk.yellow.bold(`${kitty_1.KITTY}`)} ${date} | ${chalk.red.bold(`connection closed on ${path}`)}`);
}
exports.printDisconnected = printDisconnected;
function printRequestsLog(code, method, path, port, initialTime) {
    let date = new Date().toISOString().replace(/T/, ' ').replace(/\..+/, '');
    let time = (perf_hooks_1.performance.now() - initialTime).toString();
    let repeatSpaceOnTimeExecution = 20 - time.length;
    let repeatSpaceOnMethod = 7 - method.length;
    let repeatSpaceOnPort = 5 - port.toString().length;
    switch (true) {
        case (code >= 500):
            console.log(`${chalk.yellow.bold(`${kitty_1.KITTY}`)} ${date} | ${chalk.bgRed.bold(`  ${code}  `)} | ${' '.repeat(repeatSpaceOnTimeExecution)}${time} ms | ${' '.repeat(repeatSpaceOnPort)}${port} | ${chalk.cyan.bold(`${' '.repeat(repeatSpaceOnMethod)}${method}`)}  ${chalk.blue.bold(`${path}`)}`);
            return;
        case (code >= 400 && code < 500):
            console.log(`${chalk.yellow.bold(`${kitty_1.KITTY}`)} ${date} | ${chalk.black.bgYellow.bold(`  ${code}  `)} | ${' '.repeat(repeatSpaceOnTimeExecution)}${time} ms | ${' '.repeat(repeatSpaceOnPort)}${port} | ${chalk.cyan.bold(`${' '.repeat(repeatSpaceOnMethod)}${method}`)}  ${chalk.blue.bold(`${path}`)}`);
            return;
        default:
            console.log(`${chalk.yellow.bold(`${kitty_1.KITTY}`)} ${date} | ${chalk.bgGreen.bold(`  ${code}  `)} | ${' '.repeat(repeatSpaceOnTimeExecution)}${time} ms | ${' '.repeat(repeatSpaceOnPort)}${port} | ${chalk.cyan.bold(`${' '.repeat(repeatSpaceOnMethod)}${method}`)}  ${chalk.blue.bold(`${path}`)}`);
    }
}
exports.printRequestsLog = printRequestsLog;
