"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = require("http");
const get_jsend_1 = require("../helpers/get-jsend");
const perf_hooks_1 = require("perf_hooks");
const get_request_body_1 = require("../helpers/get-request-body");
const route_shelf_1 = require("../routeShelf/route-shelf");
const request_shelf_1 = require("../requestShelf/request-shelf");
const ws_shelf_1 = require("../wsShelf/ws-shelf");
const server_upgrade_handler_1 = require("../handlers/server-upgrade-handler");
const print_functions_1 = require("../helpers/print-functions");
const pass_request_through_valitador_1 = require("../helpers/pass-request-through-valitador");
const methods_consts_1 = require("../consts/methods-consts");
class HttpMocker {
    constructor(hostname, port) {
        this.routeShelf = new route_shelf_1.default();
        this.port = port;
        this.hostname = hostname;
        this.requestShelf = new request_shelf_1.default();
        this.wsShelf = new ws_shelf_1.default();
    }
    getRouteShelf() {
        return this.routeShelf;
    }
    getWsShelf() {
        return this.wsShelf;
    }
    getRequestShelf() {
        return this.requestShelf;
    }
    getServerInstance() {
        return this.server;
    }
    loadServer() {
        this.server = http_1.createServer((req, res) => {
            let initialTime = perf_hooks_1.performance.now();
            let ok = req.url.includes('/=%5E.%5E=/');
            let path = ok ? req.url.split('?', 1)[0] : req.url;
            this.routeShelf.getItem(path, req.method).then((route) => __awaiter(this, void 0, void 0, function* () {
                if (typeof route.response != 'function') {
                    let response = route.response;
                    if (route.validator)
                        get_request_body_1.default(req).then(body => {
                            let defaultValidator = route.validator.find(validator => validator.matchers.body == '*');
                            let validatorsWithoutDefault = route.validator.filter(valitator => valitator.matchers.body != '*');
                            for (let i = 0; i < validatorsWithoutDefault.length; i++) {
                                try {
                                    let validatorResponse = pass_request_through_valitador_1.default(body, req, validatorsWithoutDefault[i]);
                                    if (validatorResponse.ok) {
                                        this.respRequest(res, validatorsWithoutDefault[i].code, validatorsWithoutDefault[i].body, {
                                            method: req.method,
                                            path: req.url
                                        }, req.socket.localPort, initialTime);
                                        break;
                                    }
                                }
                                catch (validatorResponse) {
                                    this.respRequest(res, 500, validatorResponse.message, {
                                        method: req.method,
                                        path: req.url
                                    }, req.socket.localPort, initialTime);
                                    break;
                                }
                                if (i == validatorsWithoutDefault.length - 1)
                                    if (defaultValidator)
                                        this.respRequest(res, defaultValidator.code, defaultValidator.body, {
                                            method: req.method,
                                            path: req.url
                                        }, req.socket.localPort, initialTime);
                                    else
                                        this.respRequest(res, 404, undefined, {
                                            method: req.method,
                                            path: req.url
                                        }, req.socket.localPort, initialTime);
                            }
                        }).catch(() => {
                            this.respRequest(res, 500, get_jsend_1.default({
                                statusCode: 500,
                                data: undefined,
                                message: undefined
                            }), { method: req.method, path: req.url }, req.socket.localPort, initialTime);
                        });
                    else
                        this.respRequest(res, response.code, response.body, {
                            method: req.method,
                            path: req.url
                        }, req.socket.localPort, initialTime);
                }
                else {
                    let handle = route.response;
                    return handle(req).then((resp) => {
                        this.respRequest(res, resp.code, resp.body, {
                            method: req.method,
                            path: req.url
                        }, req.socket.localPort, initialTime);
                    });
                }
                this.hydrateRequest(req).then(request => {
                    this.requestShelf.setRequest(req.method.toUpperCase() + req.url, request);
                });
            })).catch((code) => {
                if (req.method.toLocaleUpperCase() == methods_consts_1.OPTIONS && code == 405) {
                    this.respRequest(res, 204, undefined, {
                        method: req.method,
                        path: req.url
                    }, req.socket.localPort, initialTime);
                    return;
                }
                if (typeof code == 'number')
                    this.respRequest(res, code, get_jsend_1.default({
                        statusCode: code,
                        data: undefined,
                        message: undefined
                    }), { method: req.method, path: req.url }, req.socket.localPort, initialTime);
                else
                    this.respRequest(res, 500, get_jsend_1.default({
                        statusCode: 500,
                        data: undefined,
                        message: undefined
                    }), { method: req.method, path: req.url }, req.socket.localPort, initialTime);
            });
        });
        this.server.on('upgrade', (request, socket, head) => {
            new server_upgrade_handler_1.default(this.wsShelf, request, socket, head).handle();
        });
    }
    runServer() {
        return new Promise((resolve, reject) => {
            this.server.listen(Number(this.port), this.hostname, () => {
                resolve(`New mocker running at http://${this.hostname}:${this.port}/`);
            });
            this.server.on('error', (e) => {
                if (e.code === 'EADDRINUSE')
                    reject(`Address ${this.hostname}:${this.port} already in use...`);
            });
        });
    }
    addRoute(route) {
        console.log('New route added to mocker on port ' + this.port + ' | ' + ' '.repeat(7 - route.filters.method.length) + route.filters.method + ' ' + route.filters.path);
        this.routeShelf.setItem(route);
    }
    stopServer() {
        console.log('Closing mocker on port ' + this.port);
        return new Promise((resolve, reject) => this.server.close((error) => {
            if (error) {
                reject(error);
            }
            else {
                resolve(undefined);
                console.log('Mocker ' + this.port + ' closed!');
            }
        }));
    }
    respRequest(res, code, body, reqFilter, port, initialTime) {
        if (reqFilter.path == '/' && reqFilter.method == methods_consts_1.DELETE)
            res.setHeader('Connection', 'close');
        res.writeHead(code, {
            'Content-Type': 'application/json',
            'Access-Control-Allow-Origin': '*',
            'Access-Control-Allow-Methods': '*'
        });
        res.end(body, () => {
            print_functions_1.printRequestsLog(code, reqFilter.method, reqFilter.path, port, initialTime);
        });
    }
    hydrateRequest(req) {
        return __awaiter(this, void 0, void 0, function* () {
            let body = yield get_request_body_1.default(req);
            return {
                ip: req.socket.remoteAddress,
                header: req.headers,
                body: body,
                method: req.method,
                url: req.url,
                date: new Date().toString()
            };
        });
    }
}
exports.default = HttpMocker;
