"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class RouteShelf {
    constructor() {
        this.routesList = [];
    }
    getItem(path, method) {
        return new Promise((resolve, reject) => {
            let routes = this.filterRoutesByPath(this.routesList, path);
            if (routes.length == 0) {
                return reject(404);
            }
            let route = this.getRouteByMethod(routes, method.toUpperCase());
            if (route) {
                return resolve(route);
            }
            reject(405);
        });
    }
    getItems() {
        return this.routesList;
    }
    setItem(route) {
        route.filters.method = route.filters.method.toUpperCase();
        let routeItem = this.getRouteByPathAndMethod(this.routesList, route.filters);
        if (!routeItem) {
            this.routesList.push(route);
        }
        return !routeItem;
    }
    updateItem(routePath, routeMethod, route) {
        route.filters = { path: routePath, method: routeMethod.toUpperCase() };
        let routeItem = this.getRouteByPathAndMethod(this.routesList, route.filters);
        if (routeItem) {
            this.routesList = this.filterPathAndMethodDifferentsRoutes(this.routesList, {
                path: route.filters.path,
                method: route.filters.method
            });
            this.routesList.push(route);
        }
        return !!routeItem;
    }
    removeItem(routePath, routeMethod) {
        let routeItem = this.getRouteByPathAndMethod(this.routesList, {
            path: routePath,
            method: routeMethod.toUpperCase()
        });
        if (routeItem) {
            this.routesList = this.filterPathAndMethodDifferentsRoutes(this.routesList, {
                path: routePath,
                method: routeMethod.toUpperCase()
            });
        }
        return !!routeItem;
    }
    filterRoutesByPath(routesList, path) {
        return routesList.filter((route) => route.filters.path == path);
    }
    filterPathAndMethodDifferentsRoutes(routesList, { path, method }) {
        return routesList.filter((route) => route.filters.path != path || route.filters.method != method);
    }
    getRouteByPathAndMethod(routesList, { path, method }) {
        return routesList.find((routeItem) => routeItem.filters.path == path && routeItem.filters.method == method);
    }
    getRouteByMethod(routesList, method) {
        return routesList.find((routeItem) => routeItem.filters.method == method);
    }
}
exports.default = RouteShelf;
