"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const httpMocker_1 = require("./mocker/httpMocker");
const create_http_mocker_handler_1 = require("./handlers/create-http-mocker-handler");
const methods_consts_1 = require("./consts/methods-consts");
const lodash_1 = require("lodash");
const check_params_config_1 = require("./helpers/check-params-config");
function server(config) {
    return new Promise((resolve, reject) => {
        let host = config.host || '0.0.0.0';
        let port = config.serverPort || '4000';
        let rangeArray = config.mockersPortsRange || '5000-6000';
        if (config.host != undefined && config.serverPort != undefined && config.mockersPortsRange != undefined) {
            let err = check_params_config_1.default(config);
            if (err) {
                return reject(err);
            }
        }
        const [portInit, portLimit] = getPortsArray(rangeArray);
        const server = new httpMocker_1.default(host, Number(port));
        server.loadServer();
        server.runServer().then((res) => {
            server.addRoute({
                filters: { path: '/create', method: methods_consts_1.POST },
                response: create_http_mocker_handler_1.default.prototype.handle.bind(new create_http_mocker_handler_1.default(host, lodash_1.range(Number(portInit), Number(portLimit), 1)))
            });
            resolve(server);
        }).catch(reject);
    });
}
exports.default = server;
function getPortsArray(text) {
    return text.split('-');
}
